/// <reference types="react" />
import * as React from 'react';
import PropTypes from 'prop-types';
export interface AbstractSelectProps {
    prefixCls?: string;
    className?: string;
    size?: 'default' | 'large' | 'small';
    notFoundContent?: React.ReactNode | null;
    transitionName?: string;
    choiceTransitionName?: string;
    showSearch?: boolean;
    allowClear?: boolean;
    disabled?: boolean;
    style?: React.CSSProperties;
    tabIndex?: number;
    placeholder?: string;
    defaultActiveFirstOption?: boolean;
    dropdownClassName?: string;
    dropdownStyle?: React.CSSProperties;
    dropdownMenuStyle?: React.CSSProperties;
    onDropdownMouseDown?: (e: React.MouseEvent<any>) => void;
    onSearch?: (value: string) => any;
    filterOption?: boolean | ((inputValue: string, option: React.ReactElement<OptionProps>) => any);
}
export interface LabeledValue {
    key: string;
    label: React.ReactNode;
}
export declare type SelectValue = string | any[] | LabeledValue | LabeledValue[];
export interface SelectProps extends AbstractSelectProps {
    value?: SelectValue;
    defaultValue?: SelectValue;
    mode?: 'default' | 'multiple' | 'tags' | 'combobox';
    optionLabelProp?: string;
    onInput?: (value: SelectValue) => void;
    onChange?: (value: SelectValue, option: React.ReactElement<any> | React.ReactElement<any>[]) => void;
    onSelect?: (value: SelectValue, option: React.ReactElement<any>) => any;
    onDeselect?: (value: SelectValue) => any;
    onBlur?: () => any;
    onFocus?: () => any;
    onPopupScroll?: () => any;
    onInputKeyDown?: (e: React.KeyboardEvent<HTMLInputElement>) => void;
    onChoiceItemClick?: (value: SelectValue, option: React.ReactElement<any>) => void;
    maxTagCount?: number;
    maxTagPlaceholder?: React.ReactNode | ((omittedValues: SelectValue[]) => React.ReactNode);
    dropdownMatchSelectWidth?: boolean;
    optionFilterProp?: string;
    labelInValue?: boolean;
    getPopupContainer?: (triggerNode: Element) => HTMLElement;
    tokenSeparators?: string[];
    getInputElement?: () => React.ReactElement<any>;
    autoFocus?: boolean;
    showNotFindInputItem?: boolean;
    showNotFindSelectedItem?: boolean;
    getRootDomNode?: () => HTMLElement;
    showCheckAll?: boolean;
    filter?: boolean;
    filterPlaceholder?: string;
    footer?: React.ReactNode | string;
    choiceRender?: (liDom: HTMLElement, value: SelectValue) => any;
    loading?: boolean | object;
    choiceRemove?: boolean;
}
export interface OptionProps {
    disabled?: boolean;
    value?: any;
    title?: string;
    children?: React.ReactNode;
    className?: string;
    style?: object;
}
export interface OptGroupProps {
    label?: React.ReactNode;
}
export interface SelectLocale {
    notFoundContent?: string;
    filterPlaceholder?: string;
}
export default class Select extends React.Component<SelectProps, {}> {
    static Option: React.ClassicComponentClass<OptionProps>;
    static OptGroup: React.ClassicComponentClass<OptGroupProps>;
    static defaultProps: {
        prefixCls: string;
        showSearch: boolean;
        transitionName: string;
        choiceTransitionName: string;
        filter: boolean;
        showCheckAll: boolean;
        choiceRemove: boolean;
    };
    static propTypes: {
        prefixCls: PropTypes.Requireable<string>;
        className: PropTypes.Requireable<string>;
        size: PropTypes.Requireable<string>;
        combobox: PropTypes.Requireable<boolean>;
        notFoundContent: PropTypes.Requireable<any>;
        showSearch: PropTypes.Requireable<boolean>;
        optionLabelProp: PropTypes.Requireable<string>;
        transitionName: PropTypes.Requireable<string>;
        choiceTransitionName: PropTypes.Requireable<string>;
        showNotFindInputItem: PropTypes.Requireable<boolean>;
        showNotFindSelectedItem: PropTypes.Requireable<boolean>;
        filter: PropTypes.Requireable<boolean>;
        showCheckAll: PropTypes.Requireable<boolean>;
        footer: PropTypes.Requireable<string | number | boolean | {} | PropTypes.ReactElementLike | PropTypes.ReactNodeArray>;
        choiceRender: PropTypes.Requireable<(...args: any[]) => any>;
        loading: PropTypes.Requireable<boolean | object>;
        filterValue: PropTypes.Requireable<string>;
        onFilterChange: PropTypes.Requireable<(...args: any[]) => any>;
        choiceRemove: PropTypes.Requireable<boolean | ((...args: any[]) => any)>;
        onChoiceRemove: PropTypes.Requireable<(...args: any[]) => any>;
    };
    private rcSelect;
    focus(): void;
    blur(): void;
    saveSelect: (node: any) => void;
    getNotFoundContent(locale: SelectLocale): {} | null | undefined;
    renderSelect: (locale: SelectLocale) => JSX.Element;
    render(): JSX.Element;
}
